@@ -79,10 +79,11 @@ class CommandLineWriter(Writer):
 
             if '_total_time' in engine.buffer.keys():
                 total_time = engine.buffer.latest('_total_time')
-                num_iter_passed = engine.iter + 1 - engine.start_iter
-                num_iter_left = engine.max_iters - engine.iter - 1
+                num_iters_passed = engine.iter + 1 - engine.start_iter
+                num_iters_left = engine.max_iters - engine.iter - 1
                 eta = timedelta(
-                    seconds=int(num_iter_left * total_time / num_iter_passed))
+                    seconds=int(num_iters_left * total_time /
+                                num_iters_passed))
                 log += 'eta: {}, '.format(eta)
 
             for key in ['time', 'data_time']:
@@ -232,14 +233,14 @@ class TensorboardWriter(Writer):
 @HOOKS.register()
 class EventWriterHook(Hook):
     """
-    Write logs every specified step during training. This hook relies on
+    Write logs periodically during training. This hook relies on
     :obj:`TimerHook` and it works with several :obj:`Writer` objects to log
     metrics, images, videos, audios, etc. In distributed training, only the
     main process will write the logs.
 
     Args:
-        interval (int, optional): The interval of writing logs. Default:
-            ``50``.
+        interval (int, optional): The interval of iterations to write logs.
+            Default: ``50``.
         writers (list[:obj:`Writer`] or list[str], optional): The list of
             writers or name of writers to use. Currently supported writers
             include :obj:`CommandLineWriter`, :obj:`JSONWriter` and
