@@ -1,11 +1,12 @@
 # Copyright (c) Ye Liu. All rights reserved.
 
 from .activation import ACTIVATIONS, Clamp, EffSwish, Swish, build_act_layer
+from .conv import CONVS, build_conv_layer
 from .msg_pass import GAT, GCN, MESSAGE_PASSINGS, SGC, build_msg_pass_layer
 from .norm import NORMS, build_norm_layer
 
 __all__ = [
-    'ACTIVATIONS', 'Clamp', 'EffSwish', 'Swish', 'build_act_layer', 'GAT',
-    'GCN', 'MESSAGE_PASSINGS', 'SGC', 'build_msg_pass_layer', 'NORMS',
-    'build_norm_layer'
+    'ACTIVATIONS', 'Clamp', 'EffSwish', 'Swish', 'build_act_layer', 'CONVS',
+    'build_conv_layer', 'GAT', 'GCN', 'MESSAGE_PASSINGS', 'SGC',
+    'build_msg_pass_layer', 'NORMS', 'build_norm_layer'
 ]
